import React from 'react';
import { matchPath, Route } from 'react-router';
import invariant from 'tiny-invariant';
import { useNamedRouting } from './hooks';
export const NamedSwitch = ({ location: locationFromProps, children }) => {
    const context = useNamedRouting();
    invariant(context, 'You should not use <NamedSwitch> outside a <NamedRouter>');
    const location = locationFromProps || context.location;
    return (React.createElement(Route, null, ({ match: parentMatch }) => {
        let element = null;
        let match = null;
        React.Children.forEach(children, (child) => {
            if (match === null && React.isValidElement(child)) {
                element = child;
                const path = child.props.name ? context.getRawPath(child.props.name) : child.props.from;
                const route = child.props.name ? context.getRoute(child.props.name) : {};
                match = path
                    ? matchPath(location.pathname, Object.assign({}, route, child.props, { path }))
                    : parentMatch;
            }
        });
        return match && element
            ? React.cloneElement(element, { location, computedMatch: match })
            : null;
    }));
};
NamedSwitch.displayName = 'NamedSwitch';
